@@ -24,7 +24,7 @@ tempDir = "/data"
 class Releasor(object):
     def __init__(self, args):
         self.versionstotreat = [
-            {"v": "6", "ubuntuVersions": ["oracular", "plucky"]},
+            {"v": "6", "ubuntuVersions": ["questing"]},
         ]
         self.workdingDir = os.path.join(tempDir, "skrooge-release_" + args.version)
         print("# Working directory :" + self.workdingDir)
@@ -133,7 +133,6 @@ class Releasor(object):
                 "cmake",
                 "..",
                 "-DCMAKE_INSTALL_PREFIX=/usr",
-                "-DQT_PLUGIN_INSTALL_DIR=/usr/lib/x86_64-linux-gnu/qt6/plugins",
             ]
             self.logfile.write("### " + " ".join(cmd) + "\n")
             rc = subprocess.call(cmd, stdout=self.logfile, stderr=self.logfile)
